@@ -48,18 +48,6 @@ subtype 'qf_interest_rate_type', as Str, where {
     "Invalid interest_rate type $_. Must be one of: " . join(', ', @interest_rate_types)
 };
 
-=head2 qf_cutoff_code
-
-A volatility surface cutoff time convention
-
-=cut
-
-subtype 'qf_cutoff_code', as Str, where {
-    /^(?:Bangkok|Beijing|Bucharest|Budapest|Colombia|Frankfurt|Hanoi|Istanbul|Jakarta|Kuala Lumpur|London|Manila|Mexico|Moscow|Mumbai|New York|PTAX \(Ask\)|Santiago|Sao Paulo|Seoul|Singapore|Taipei|Taiwan|Tel Aviv|Tokyo|UTC|GMT|Warsaw|Wellington) \d{1,2}:\d{2}$/;
-}, message {
-    'Invalid cutoff_code [' . $_ . ']';
-};
-
 =head2 qf_surface_type
 
 Volatility surface types.
@@ -74,7 +62,4 @@ subtype 'qf_surface_type', as Str, where {
     "Invalid surface type $_. Must be one of: " . join(', ', @surface_types);
 };
 
-subtype 'qf_cutoff_helper', as 'Quant::Framework::VolSurface::Cutoff';
-coerce 'qf_cutoff_helper', from 'Str', via { Quant::Framework::VolSurface::Cutoff->new($_) };
-
 1;
